Index: chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java |
diff --git a/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java b/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java |
index 2630d9758d0563b0e2578c9ce8eea74e62b0b423..44f02a39c68203bdc0c5ee28cb1d7384f04a0b43 100644 |
--- a/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java |
+++ b/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java |
@@ -40,7 +40,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome |
ThreadUtils.runOnUiThreadBlocking(new Runnable() { |
@Override |
public void run() { |
- CommandLine.initFromFile("/data/local/tmp/chromium-testshell-command-line"); |
+ CommandLine.initFromFile("/data/local/tmp/chrome-shell-command-line"); |
try { |
BrowserStartupController.get(targetContext).startBrowserProcessesSync( |
BrowserStartupController.MAX_RENDERERS_LIMIT); |
@@ -93,7 +93,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome |
runTestOnUiThread(new Runnable() { |
@Override |
public void run() { |
- TestShellTab tab = activity.getActiveTab(); |
+ ChromeShellTab tab = activity.getActiveTab(); |
if (tab != null) { |
isLoaded.set(!tab.isLoading() |
&& !TextUtils.isEmpty(tab.getContentView().getUrl())); |
@@ -112,7 +112,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome |
} |
/** |
* Clear all files and folders in the Chromium testshell's application directory except 'lib'. |
* |
* The 'cache' directory is recreated as an empty directory. |
* |
@@ -112,7 +112,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome |
} |
/** |
- * Clear all files and folders in the Chromium testshell's application directory except 'lib'. |
+ * Clear all files and folders in the ChromeShell's application directory except 'lib'. |
* |
* The 'cache' directory is recreated as an empty directory. |